
from typing import List
from pyrdfrules.common.rule.resultrule import ResultRule
from pyrdfrules.common.rule.ruleset import Ruleset


class Result():
    """Class representing the result of a task.
    """
    
    ruleset: Ruleset = None
    """Ruleset generated by RDFRules.
    """
    
    predictionTasks: List[dict] = None
    
    data: dict
    """Raw JSON response from RDFRules."""
    
    def __init__(self, data: dict) -> None:
        """Creates a new Result object.

        Args:
            data (dict): JSON response from RDFRules.
        """
        self.data = data
        
        self._parse_data()
        
        pass
    
    def _parse_data(self):
        """Internal function translating the resulting JSON into internal object representations.
        """
        
        rules = []
        predictionTasks = []
        evaluate = []
        
        for item in self.data:                
            match item:
                case {'body': _, 'head': __, 'measures': ___}:
                    # Item is a rule
                    rule = ResultRule.model_validate(item)
                    rules.append(rule)               
                    pass
                
                case {'candidates': _, 'predictionTask': __}:
                    # Item is a prediction task
                    predictionTasks.append(item)
                    pass
                
                case {'error': _}:
                    # Item is an error
                    print("Error: " + item['error'])
                    pass
                
                case _: 
                    print("Unknown item")
                    pass
                
        self.ruleset = Ruleset(rules = rules)
        self.predictionTasks = predictionTasks
    
    def get_ruleset(self) -> Ruleset:
        """Returns the ruleset generated by RDFRules.
        """
        return self.ruleset